#! /usr/bin/perl
# nagios: -epn

# by Jean-Philippe LEMOINE - Mai 2014

use strict;
use warnings;
use Switch;
use vars qw/ $VERSION /;
use lib "/usr/lib/perl5/B";

# --------------  chargement des modules ------------------

sub try_load_module($) {
    my $module = shift;

    eval "require $module";
    if ($@) {
     print "DOMAIN UNKNOWN - Can't load module $module, ",
     "perhaps it isn't installed\n$@";
     print "Config::INI::Reader --> sudo apt-get install libconfig-ini-perl\n";
     print "Nagios::Plugin      --> sudo apt-get install libnagios-pluging-perl\n";
     exit 3;
    }

    $module->import;
   
}

BEGIN {
    try_load_module('Config::INI::Reader');
    try_load_module('Nagios::Plugin');
}

# Initialisation des variables
my $PATH_PL      = '';
my $COUNTRY_CODE = '';
my $PATH         = '';
my $NAME_INI     = '';
my $ini_file     = '';
my $hash_ref     = '';

# ---- fonctions et instructions (deportees) ------------
# define the current path as possible search path
BEGIN {
    $PATH_PL = `dirname $0`;
    $PATH_PL = substr($PATH_PL, 0, -1);
    if (substr($PATH_PL,0,2) eq "./")
        {
        $PATH_PL=substr($PATH_PL,2);
        }
}
use lib "${PATH_PL}";
# sub routines are in sub file
require "check_uptime_sub.pl";


# ------       MAIN ------------

my $VERSION = '1.1';
my $LICENCE = "Ce plugin Nagios est gratuit et libre de droits, et vous pouvez l'utiliser à votre convenance."
  . ' Il est livré avec ABSOLUMENT AUCUNE GARANTIE.';


# put the 2 letters of the country code
# in 10/28/2012, there is 2 possibilies :
# fr for french
# en for english
# can be changed if needed
my $country_code_def="fr";

# start with a / is absolute path
# with 1st directory if relative path
# can be changed if needed
my $path_to_ini="ini";

my $plugin_nagios = Nagios::Plugin->new(
  shortname => 'check_uptime',
  usage     => 'Usage : %s  -l|--lang <language code fr or en> -i|--ini_path <path ini file>',
  version   => $VERSION,
  license   => $LICENCE,
);

$plugin_nagios->add_arg(
spec     => 'lang|l=s',
help     => '<fr ou en> fr by default',    # Help of option
required => 0,                  # optionnal
);

$plugin_nagios->add_arg(
spec     => 'ini_path|i=s',
help     => 'ini path. ini by default',    # Help of option
required => 0,                  # optional
);

$plugin_nagios->getopts();

$COUNTRY_CODE = $plugin_nagios->opts->get('lang');
# check if translation file exists
# if not, try to use default one

if (!(defined($COUNTRY_CODE)))
    {
    $COUNTRY_CODE = $country_code_def;
    }


my $INI_PATH     = $plugin_nagios->opts->get('ini_path');

if (defined($INI_PATH))
    {
    $path_to_ini=$INI_PATH;
    }

# ---- get fichier ini -------------
$hash_ref = recup_fichier_ini("$path_to_ini","$COUNTRY_CODE");

# ----- get traduction texts
#label

my $result01=$hash_ref->{result}->{result01};  
# hour, min singular
my $result02=$hash_ref->{result}->{result02};
my $result03=$hash_ref->{result}->{result03};
# hour, min plural
my $result04=$hash_ref->{result}->{result04};
my $result05=$hash_ref->{result}->{result05};
#day sing plural
my $result06=$hash_ref->{result}->{result06};
my $result07=$hash_ref->{result}->{result07};

# ---- command  -------------

my $cmd1 = `uptime | awk -F"," '{print  \$1}'`;
my $cmd2 = `uptime | awk -F"," '{print  \$2}'`;
my $cmd  = "";

# ---- day exist ? -----

#is the word in the 4th position equal at day or days
my $jj = 0;
my $libj = '';
my $test = `echo -n "$cmd1" | awk '{print  \$4}'`;

$test = substr($test, 0, -1);

if (($test eq "day") || ($test eq "days"))
{
  $jj = `echo -n "$cmd1" | awk '{print  \$3}'`;
  $jj = substr($jj, 0, -1);
  # libelle du jour
  if ($jj==1)
    { $libj = `echo "$jj $result06, "`; }
  else
    { $libj = `echo "$jj $result07, "`; }
  $libj = substr($libj, 0, -1);
}

# ---- label is xxx min ou hh:mm ?

# case where there is xxx min in the 4th position
my $unite = 0;
my $dummy = '';
if ($jj == 0)
{
  $unite=`echo -n "$cmd1" | awk '{print  \$4}'`;
}
else
{
  $unite=`echo -n "$cmd2" | awk '{print  \$2}'`;
}
$unite = substr($unite, 0, -1);

my $libh = '';
my $libm = '';

if ($unite eq "min")
{
  my $mm = 0;
  if ($jj==0)
  {
    $mm=`echo "$cmd1" | awk '{print  \$3}'`;
    $mm = substr($mm, 0, -1);
  }
  else
  {
    $mm=`echo -n "$cmd2" | awk '{print  \$1}'`};
    $mm = substr($mm, 0, -1);
    if ($mm < 2 ) {$libm = $result03} else {$libm = $result05};
    print "$result01 : $libj$mm $libm \n";
  }
else
{
  # case where there is digits:digits
  if ($jj == 0)
  {
    $cmd = `echo -n "$cmd1" | awk '{print  \$3}'`;
  }
  else
  {
    #$cmd = `echo -n "$cmd" | awk '{print  \$5}'`;
    $cmd=$cmd2;
  }
  my $hh=`echo -n "$cmd" | awk -F":" '{print  \$1}'`;
  $hh = substr($hh, 0, -1);
  my $mm=`echo -n "$cmd" | awk -F":" '{print  \$2}'`;
  $mm = substr($mm, 0, -1);

  if ($hh < 2 ) {$libh = $result02} else {$libh = $result04};
  if ($mm < 2 ) {$libm = $result03} else {$libm = $result05};
  print "$result01 : $libj$hh $libh, $mm $libm \n";
}

exit 0;

